/**
 * A theme name to pass to {@link highlight} or {@link render}.
 */
export type Theme = typeof THEMES[number];
/**
 * Source code with theme-independent style information attached.
 *
 * See {@link https://rubixdev.github.io/syntastica/syntastica/type.Highlights.html | the Rust definition}
 * for more information.
 */
export type Highlights = [string, string | null][][];
/**
 * Initialize the Wasm module.
 *
 * This function _must_ be called before any of the others
 */
export declare function init(): Promise<void>;
/**
 * Load a language from a WebAssembly module.
 * The module can be provided as a path to a file or as a buffer.
 */
export declare function loadLanguage(input: string | Uint8Array): Promise<void>;
/**
 * Highlight code and render to the requested format.
 *
 * If you plan to highlight the same input multiple times, use {@link process} and {@link render} instead.
 *
 * @param code - The code to highlight.
 *
 * @param language - The name of the code's language.
 *
 * The language must have been loaded previously by calling {@link loadLanguage}.
 *
 * @param theme - The name of the theme to use.
 *
 * All themes from {@link https://rubixdev.github.io/syntastica/syntastica_themes/ | the default collection}
 * are supported. The theme name is equivalent to its Rust path specifier, so for example the gruvbox dark theme
 * is named `gruvbox::dark`.
 *
 * @param renderer - The renderer to use.
 *
 * The renderer name is either `HTML` or `Terminal` in any casing. To specify a background color
 * for the terminal renderer, append a hex color literal like `terminal#282828` or `Terminal#fff`.
 *
 * By default, the `HTML` renderer will be used.
 *
 * @returns The highlighted code as HTML code.
 *
 * See {@link https://rubixdev.github.io/syntastica/syntastica/renderer/struct.HtmlRenderer.html | here} for
 * more information on the output.
 */
export declare function highlight(code: string, language: string, theme: Theme, renderer?: string): string;
/**
 * Prepare code for rendering multiple times.
 *
 * @param code - The code to highlight.
 *
 * @param language - The name of the code's language.
 *
 * The language must have been loaded previously by calling {@link loadLanguage}.
 *
 * @returns Highlight information about the code to be used by {@link render}.
 */
export declare function process(code: string, language: string): Highlights;
/**
 * Render code that was previously processed by calling {@link process}.
 *
 * @param highlights - The processed highlight information to render.
 *
 * @param theme - The name of the theme to use.
 *
 * All themes from {@link https://rubixdev.github.io/syntastica/syntastica_themes/ | the default collection}
 * are supported. The theme name is equivalent to its Rust path specifier, so for example the gruvbox dark theme
 * is named `gruvbox::dark`.
 *
 * @param renderer - The renderer to use.
 *
 * The renderer name is either `HTML` or `Terminal` in any casing. To specify a background color
 * for the terminal renderer, append a hex color literal like `terminal#282828` or `Terminal#fff`.
 *
 * By default, the `HTML` renderer will be used.
 *
 * @returns The highlighted code in the requested format.
 */
export declare function render(highlights: Highlights, theme: Theme, renderer?: string): string;
declare const _default: {
    init: typeof init;
    loadLanguage: typeof loadLanguage;
    highlight: typeof highlight;
    process: typeof process;
    render: typeof render;
};
export default _default;
/**
 * A list of all valid themes.
 *
 * @see The {@link Theme} type.
 */
export declare const THEMES: readonly ["abscs::abscs", "aurora::aurora", "blue_moon::blue_moon", "boo::boo", "catppuccin::frappe", "catppuccin::latte", "catppuccin::macchiato", "catppuccin::mocha", "darcula::darcula", "dracula::dracula", "everblush::everblush", "everforest::dark", "everforest::light", "falcon::falcon", "github::dark", "github::dark_colorblind", "github::dark_default", "github::dark_dimmed", "github::dark_high_contrast", "github::dark_tritanopia", "github::light", "github::light_colorblind", "github::light_default", "github::light_high_contrast", "github::light_tritanopia", "gruvbox::dark", "gruvbox::light", "melange::melange", "minimal::minimal", "monochrome::monochrome", "monokai::monokai", "monokai::pro", "monokai::ristretto", "monokai::soda", "moonfly::moonfly", "moonlight::moonlight", "neon::dark", "neon::default", "neon::doom", "neon::light", "nightfly::nightfly", "nord::nord", "oceanicnext::dark", "oceanicnext::light", "omni::omni", "one::cool", "one::dark", "one::darker", "one::deep", "one::light", "one::warm", "one::warmer", "oxocarbon::dark", "oxocarbon::light", "solarized::dark", "solarized::light", "tokyo::day", "tokyo::moon", "tokyo::night", "tokyo::storm", "vscode::dark", "vscode::light", "zephyr::zephyr"];
